@@ -4,12 +4,13 @@ from django.forms import widgets
 from tendenci.addons.help_files.models import Request, HelpFile, Topic
 from tinymce.widgets import TinyMCE
 #from captcha.fields import CaptchaField
-from simplemathcaptcha.fields import MathCaptchaField
+#from simplemathcaptcha.fields import MathCaptchaField
+from tendenci.core.base.forms import SimpleMathField
 from tendenci.core.perms.forms import TendenciBaseForm
 from tendenci.apps.user_groups.models import Group
 
 class RequestForm(forms.ModelForm):
-    captcha = MathCaptchaField()
+    captcha = SimpleMathField()
     class Meta:
         model = Request
 
