@@ -5,7 +5,8 @@ from django.utils.translation import ugettext_lazy as _
 
 from tendenci.core.base.fields import EmailVerificationField
 
-from simplemathcaptcha.fields import MathCaptchaField
+#from simplemathcaptcha.fields import MathCaptchaField
+from tendenci.core.base.forms import SimpleMathField
 
 class ContactForm(forms.ModelForm):
     class Meta:
@@ -37,4 +38,4 @@ class SubmitContactForm(forms.Form):
     url = forms.URLField(label=_('URL'), max_length=200, required=False)
 
     message = forms.CharField(widget=forms.Textarea)
-    captcha = MathCaptchaField()
+    captcha = SimpleMathField()
